Documentation
=============

This is an affiliated package for the AstroPy package. The documentation for
this package is here:

.. toctree::
  :maxdepth: 1

  pydl/index.rst

.. note:: Do not edit this page - instead, place all documentation for the
          affiliated package inside ``packagename/``
